package net.wanji.feign.pojo.vo;

import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Getter;
import lombok.Setter;

import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotEmpty;
import java.util.List;

/**
 * 信号机计划下发VO
 *
 * @author wuxiaokai
 * @date 2022/11/24 15:55:08
 */
@Setter
@Getter
@ApiModel(value = "PhaseTimingSendVO", description = "信号机计划下发输入参数")
public class PlanSendVO {

    @ApiModelProperty(value = "路口编号", notes = "路口编号")
    @NotBlank(message = "路口编号不能为空")
    private String crossCode;
    @ApiModelProperty(value = "计划列表", notes = "计划列表")
    @NotEmpty(message = "计划列表不能为空")
    private List<Plan> planList;

    @Setter
    @Getter
    public static class Plan {
        /**
         * 计划号
         */
        @ApiModelProperty(value = "计划号", notes = "计划号")
        private String planNo;
        /**
         * 计划描述
         */
        @ApiModelProperty(value = "计划描述", notes = "计划描述")
        private String planDescribe;
        /**
         * 时段列表
         */
        @ApiModelProperty(value = "时段列表", notes = "时段列表")
        private List<Section> sectionList;

        @Setter
        @Getter
        public static class Section {
            /**
             * 时段号
             */
            @ApiModelProperty(value = "时段号", notes = "时段号")
            private String sectionNo;
            /**
             * 开始时间
             */
            @ApiModelProperty(value = "开始时间", notes = "开始时间")
            private String beginTime;
            /**
             * 结束时间
             */
            @ApiModelProperty(value = "结束时间", notes = "结束时间")
            private String endTime;
            /**
             * 控制模式：1定周期；2绿灯；3黄灯；4红灯；5关灯；6绿闪；7黄闪；8红闪
             */
            @ApiModelProperty(value = "控制模式：1定周期；2绿灯；3黄灯；4红灯；5关灯；6绿闪；7黄闪；8红闪", notes = "")
            private String controlMode;
            /**
             * 方案号
             */
            @ApiModelProperty(value = "方案号", notes = "")
            private String patternNo;
        }
    }
}
