package net.wanji.feign.pojo.vo;

import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import lombok.Getter;
import lombok.Setter;

import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotEmpty;
import java.util.List;
@Data
@ApiModel(value = "PhaseTimingSendVO", description = "信号机方案下发输入参数")
public class SchemeSendVO {

    @ApiModelProperty(value = "路口编号", notes = "路口编号")
    @NotBlank(message = "路口编号不能为空")
    private String crossCode;

    @ApiModelProperty(value = "方案列表", notes = "方案列表")
    @NotEmpty(message = "方案列表不能为空")
    private List<Pattern> patternList;

    /**
     * 方案
     */
    @Setter
    @Getter
    public static class Pattern {

        /**
         * 方案号
         */
        @ApiModelProperty(value = "方案号", notes = "")
        private String patternNo;
        /**
         * 方案名称
         */
        @ApiModelProperty(value = "方案名称", notes = "")
        private String patternName;
        /**
         * 方案周期
         */
        @ApiModelProperty(value = "方案周期", notes = "")
        private String cycle;
        /**
         * 协调相位号
         */
        @ApiModelProperty(value = "协调相位号", notes = "")
        private String coordPhase;
        /**
         * 协调相位差
         */
        @ApiModelProperty(value = "协调相位差", notes = "协调相位差")
        private String offset;

        @ApiModelProperty(value = "环列表", notes = "环列表")
        private List<Ring> rings;

        @Setter
        @Getter
        public static class Ring {

            @ApiModelProperty(value = "环号", notes = "环号")
            private String ringNo;

            @ApiModelProperty(value = "相位列表", notes = "相位列表")
            private List<Phase> phaseList;

            /**
             * 相位
             */
            @Setter
            @Getter
            public static class Phase {

                /**
                 * 相位号
                 */
                @ApiModelProperty(value = "相位号", notes = "")
                private String phaseNo;
                /**
                 * 相位名称
                 */
                @ApiModelProperty(value = "相位名称", notes = "")
                private String phaseName;
                /**
                 * 相位序号
                 */
                @ApiModelProperty(value = "相位序号", notes = "")
                private String sort;
                /**
                 * 控制模式：1定周期；2绿灯；3黄灯；4红灯；5关灯；6绿闪；7黄闪；8红闪
                 */
                @ApiModelProperty(value = "控制模式：1定周期；2绿灯；3黄灯；4红灯；5关灯；6绿闪；7黄闪；8红闪", notes = "")
                private String controlMode;
                /**
                 * 最小绿灯时间
                 */
                @ApiModelProperty(value = "最小绿灯时间", notes = "")
                private String minGreenTime;
                /**
                 * 最大绿灯时间
                 */
                @ApiModelProperty(value = "最大绿灯时间", notes = "")
                private String maxGreenTime;
                /**
                 * 相位时间
                 */
                @ApiModelProperty(value = "相位时间", notes = "")
                private String phaseTime;
                /**
                 * 绿灯时间
                 */
                @ApiModelProperty(value = "绿灯时间", notes = "")
                private String greenTime;
                /**
                 * 绿闪时间
                 */
                @ApiModelProperty(value = "绿闪时间", notes = "")
                private String greenFlashTime;
                /**
                 * 行闪时间
                 */
                @ApiModelProperty(value = "行闪时间", notes = "")
                private String pedFlashTime;
                /**
                 * 黄灯时间
                 */
                @ApiModelProperty(value = "黄灯时间", notes = "")
                private String yellowTime;
                /**
                 * 红灯时间
                 */
                @ApiModelProperty(value = "红灯时间", notes = "")
                private String redTime;

            }

            //@Setter
            //@Getter
            //public static class Lights {
            //
            //    /**
            //     * 灯组号
            //     */
            //    @ApiModelProperty(value = "灯组号", notes = "")
            //    private String lightsNo;
            //    /**
            //     * 灯组名称
            //     */
            //    @ApiModelProperty(value = "灯组名称", notes = "")
            //    private String name;
            //    /**
            //     * 灯组类型：1箭头;2圆饼，3行人
            //     */
            //    @ApiModelProperty(value = "灯组类型：1箭头2圆饼3行人", notes = "")
            //    private String type;
            //    /**
            //     * 灯组方向：1北；2东北；3东；4东南；5南；6西南；7西；8西北
            //     */
            //    @ApiModelProperty(value = "灯组方向：1北；2东北；3东；4东南；5南；6西南；7西；8西北", notes = "")
            //    private String dir;
            //    /**
            //     * 灯组转向：1左转；2右转；3直行；4左掉头；5直左；6直右；7右掉头；8向左合流；9向右合流；10左转加掉头；11右转加掉头；12直行加左掉头；13直行加右掉头；14左转右转；15左直右；16左转右转加掉头；17左直掉头；18左直右掉头；20行人
            //     */
            //    @ApiModelProperty(value = "灯组转向：1左转；2右转；3直行；4左掉头；5直左；6直右；7右掉头；8向左合流；9向右合流；10左转加掉头；11右转加掉头；12直行加左掉头；13直行加右掉头；14左转右转；15左直右；16左转右转加掉头；17左直掉头；18左直右掉头；20行人", notes = "")
            //    private String turn;
            //    /**
            //     * 行人进出口：1进口;2出口，3进出口
            //     */
            //    @ApiModelProperty(value = "行人进出口：1进口2出口，3进出口", notes = "")
            //    private String inOutType;
            //}
        }

    }
}
